<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'travel_master_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','travel-master-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_featured_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );

if ( $options['home_layout'] == 'fifth-design' ):

// popular destination read more setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[featured_title]', array(
	'default'			=> $options['featured_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[featured_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_featured_section',
	'active_callback' 	=> 'travel_master_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[featured_title]', array(
		'selector'            => '#magazine-featured-posts div.section-header h2.section-title',
		'settings'            => 'travel_master_pro_theme_options[featured_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_featured_title_partial',
    ) );
}

endif;

if ( $options['home_layout'] !== 'fifth-design' ):

// popular destination read more setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[featured_read_more]', array(
	'default'			=> $options['featured_read_more'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[featured_read_more]', array(
	'label'           	=> esc_html__( 'Read More Text', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_featured_section',
	'active_callback' 	=> 'travel_master_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

endif;

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'travel_master_pro_sanitize_number_range',
	'validate_callback' => 'travel_master_pro_validate_featured_count',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-master-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_featured_section',
	'active_callback'   => 'travel_master_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Featured content type control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'travel_master_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_master_pro_is_featured_section_enable',
	'choices'			=> travel_master_pro_featured_content_type(),
) );

for ( $i=1; $i <= $options['featured_count']; $i++ ) { 
	// featured pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_featured_section',
		'choices'			=> travel_master_pro_page_choices(),
		'active_callback'	=> 'travel_master_pro_is_featured_section_content_page_enable',
	) ) );

	// featured posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_featured_section',
		'choices'			=> travel_master_pro_post_choices(),
		'active_callback'	=> 'travel_master_pro_is_featured_section_content_post_enable',
	) ) );

	// featured trips drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[featured_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[featured_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_featured_section',
		'choices'			=> travel_master_pro_trip_choices(),
		'active_callback'	=> 'travel_master_pro_is_featured_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-master-pro' ),
	'description'      	=> esc_html__( 'Note: Featured selected no of posts will be shown from selected category', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_featured_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[featured_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[featured_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_featured_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_featured_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[featured_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[featured_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_featured_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_featured_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[featured_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[featured_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_featured_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_featured_section_content_destination_enable'
) ) );

