<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'travel_master_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','travel-master-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_subscription_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );

// subscription description setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[subscription_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[subscription_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_subscription_section',
	'active_callback' 	=> 'travel_master_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[subscription_sub_title]', array(
		'selector'            => '#subscribe-now .section-header p.section-subtitle',
		'settings'            => 'travel_master_pro_theme_options[subscription_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_subscription_sub_title_partial',
    ) );
}

// subscription title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_subscription_section',
	'active_callback' 	=> 'travel_master_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-now .section-header h2.section-title',
		'settings'            => 'travel_master_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_subscription_title_partial',
    ) );
}

// subscription btn title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_subscription_section',
	'active_callback' 	=> 'travel_master_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[subscription_btn_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[subscription_btn_color]',
		array(
			'section'		=> 'travel_master_pro_subscription_section',
			'label'			=> esc_html__( 'Btn Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[subscription_btn_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[subscription_btn_hover_color]',
		array(
			'section'		=> 'travel_master_pro_subscription_section',
			'label'			=> esc_html__( 'Btn Hover Color', 'travel-master-pro' ),

		)
	)
); 

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[subscription_btn_text_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[subscription_btn_text_color]',
		array(
			'section'		=> 'travel_master_pro_subscription_section',
			'label'			=> esc_html__( 'Btn Text Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[subscription_btn_text_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[subscription_btn_text_hover_color]',
		array(
			'section'		=> 'travel_master_pro_subscription_section',
			'label'			=> esc_html__( 'Btn Text Hover Color', 'travel-master-pro' ),

		)
	)
); 

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[subscription_btn_border_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[subscription_btn_border_color]',
		array(
			'section'		=> 'travel_master_pro_subscription_section',
			'label'			=> esc_html__( 'Btn Border Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[subscription_btn_border_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[subscription_btn_border_hover_color]',
		array(
			'section'		=> 'travel_master_pro_subscription_section',
			'label'			=> esc_html__( 'Btn Border Hover Color', 'travel-master-pro' ),

		)
	)
); 