<?php
/**
 * video Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add video section
$wp_customize->add_section( 'travel_master_pro_video_section', array(
	'title'             => esc_html__( 'video','travel-master-pro' ),
	'description'       => esc_html__( 'video Section options.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// video content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_section_enable]', array(
	'default'			=> 	$options['video_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[video_section_enable]', array(
	'label'             => esc_html__( 'video Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_video_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );

// video title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_video_section',
	'active_callback' 	=> 'travel_master_pro_is_video_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[video_title]', array(
		'selector'            => '#latest-posts .section-header h2.section-title',
		'settings'            => 'travel_master_pro_theme_options[video_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_video_title_partial',
    ) );
}

// video btn title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_video_section',
	'active_callback' 	=> 'travel_master_pro_is_video_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[video_btn_title]', array(
		'selector'            => '#latest-posts a.more-link',
		'settings'            => 'travel_master_pro_theme_options[video_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_video_btn_title_partial',
    ) );
}

// video btn title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_video_section',
	'active_callback' 	=> 'travel_master_pro_is_video_section_enable',
	'type'				=> 'url',
) );

// video content type control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_content_type]', array(
	'default'          	=> $options['video_content_type'],
	'sanitize_callback' => 'travel_master_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_video_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_master_pro_is_video_section_enable',
	'choices'			=> array(
		'page'	=> esc_html__('Page', 'travel-master-pro'),
		'category'	=> esc_html__('Category', 'travel-master-pro'),
		'post'	=> esc_html__('Post', 'travel-master-pro'),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_count]', array(
	'default'          	=> $options['video_count'],
	'sanitize_callback' => 'travel_master_pro_sanitize_number_range',
	'validate_callback' => 'travel_master_pro_validate_video_count',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-master-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_video_section',
	'active_callback'   => 'travel_master_pro_is_video_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['video_count']; $i++ ) :

	$wp_customize->add_setting( 'travel_master_pro_theme_options[video_url_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'travel_master_pro_theme_options[video_url_'.$i.']', array(
		'label'           	=> esc_html__( 'Video Url ', 'travel-master-pro' ).$i,
		'section'        	=> 'travel_master_pro_video_section',
		'active_callback' 	=> 'travel_master_pro_is_video_section_enable',
		'type'				=> 'url',
	) );

	$wp_customize->add_setting( 'travel_master_pro_theme_options[video_sub_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_master_pro_theme_options[video_sub_title_'.$i.']', array(
		'label'           	=> esc_html__( 'Sub Title ', 'travel-master-pro' ).$i,
		'section'        	=> 'travel_master_pro_video_section',
		'active_callback' 	=> 'travel_master_pro_is_video_section_enable',
		'type'				=> 'text',
	) );

	// video pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[video_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[video_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_video_section',
		'choices'			=> travel_master_pro_page_choices(),
		'active_callback'	=> 'travel_master_pro_is_video_section_content_page_enable',
	) ) );

	// video posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[video_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[video_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_video_section',
		'choices'			=> travel_master_pro_post_choices(),
		'active_callback'	=> 'travel_master_pro_is_video_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'travel_master_pro_theme_options[video_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_master_pro_theme_options[video_hr_'. $i .']',
		array(
			'section'         => 'travel_master_pro_video_section',
			'active_callback' => 'travel_master_pro_is_video_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[video_content_category]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[video_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-master-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_video_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_video_section_content_category_enable'
) ) );


